## Discrete Bayes

The discrete Bayes filter provides functions for Bayesian filtering with discrete probability distributions.

::: bayesian_filters.discrete_bayes.discrete_bayes.normalize

-----

::: bayesian_filters.discrete_bayes.discrete_bayes.update

-----

::: bayesian_filters.discrete_bayes.discrete_bayes.predict
